#!/bin/sh
# update dspam data from mailrelay daily
source /etc/profile
DSPAM_CONFIGDIR="/etc"

read_dspam_params() {
	local PARAMETER VALUE
	local INCLUDE_DIRS
	INCLUDE_DIRS=$(awk "BEGIN { IGNORECASE=1; } \$1==\"Include\" { print \$2 \"/*.conf\"; }" "${DSPAM_CONFIGDIR}/dspam.conf" 2>/dev/null)
	for PARAMETER in $@ ; do
		VALUE=$(awk "BEGIN { IGNORECASE=1; } \$1==\"${PARAMETER}\" { print \$2; exit; }" "${DSPAM_CONFIGDIR}/dspam.conf" ${INCLUDE_DIRS[@]} 2>/dev/null)
		[ ${?} = 0 ] || return 1
		eval ${PARAMETER/.*}=\"${VALUE}\"
	done
	return 0
}


echo_date(){
    echo "$(date): $1"
}

get_update_data(){
    DATA_FILE_ZIP="/tmp/dspam.7z"
    DATA_FILE="/tmp/dspam.csv"
    DATE=`/bin/date --date='1 day ago' +%Y-%m-%d`;
    echo_date "Get Update Data: dspam_$DATE.7z"

    wget --no-check-certificate -O $DATA_FILE_ZIP -o /dev/null "https://www.mailrelay.cn/static/dspam/dspam_$DATE.7z"
    RESULT=$?

    if [ ${RESULT} -ne 0 ]; then
        echo_date "Error: unable to download update data!"
        exit 1
    fi
    7za -o/tmp -y x $DATA_FILE_ZIP
}

update_dspam(){
    echo_date "Update Dspam start"

    local UPDATE_SQL_FILE="/dspam_update.sql";
    read_dspam_params PgSQLServer${PROFILE} PgSQLPort${PROFILE} PgSQLUser${PROFILE} PgSQLPass${PROFILE} PgSQLDb${PROFILE} && \
	[ -n "${PgSQLServer}" -a -n "${PgSQLUser}" -a -n "${PgSQLDb}" ]
    PGPASSWORD=${PgSQLPass} psql -U  ${PgSQLUser} -d ${PgSQLDb} -p ${PgSQLPort} -h ${PgSQLServer} -f ${UPDATE_SQL_FILE};
    PGPASSWORD=${PgSQLPass} psql -U  ${PgSQLUser} -d ${PgSQLDb} -p ${PgSQLPort} -h ${PgSQLServer} -c "INSERT INTO dspam_virtual_uids (username) SELECT 'umail' WHERE NOT EXISTS ( SELECT uid FROM dspam_virtual_uids WHERE username = 'umail');"
    echo_date "Update Dspam end"
}

get_update_data
update_dspam

