#coding=utf-8
"""
Django settings for operation project.

Generated by 'django-admin startproject' using Django 1.11.3.

For more information on this file, see
https://docs.djangoproject.com/en/1.11/topics/settings/

For the full list of settings and their values, see
https://docs.djangoproject.com/en/1.11/ref/settings/
"""

import os

# Build paths inside the project like this: os.path.join(BASE_DIR, ...)
BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))


# Quick-start development settings - unsuitable for production
# See https://docs.djangoproject.com/en/1.11/howto/deployment/checklist/

# SECURITY WARNING: keep the secret key used in production secret!
# SECRET_KEY = '!6esk#ch-l-rtdx+@*hf*np+k9@**3n$nc3_x=_=6q(ex)#y7)'
# WEBVUE_JWT_SECRET_KEY = '^5e8do&qc=_oe2%7(ielne6lulac1u73j6$h+qp^dp34)6^9f5'
SECRET_KEY = '{SECRET_KEY}'
WEBVUE_JWT_SECRET_KEY = '{WEBVUE_JWT_SECRET_KEY}'

# SECURITY WARNING: don't run with debug turned on in production!
DEBUG = False

ALLOWED_HOSTS = ["127.0.0.1", "operation"]
FAIL2BAN_SETTING_FILE = '/etc/fail2ban/jail.conf'

# 等保专用，隐藏 邮箱账号管理 添加用户 用户信息 部分值为False , 正常情况下应该为True（默认情况）
# HTML_ADD_ACCOUNT_PROFILE_SHOW = True
# 蓝凌API配置 为True时显示，为False时隐藏（默认情况）
# LANDRAY_API = False

# Application definition

INSTALLED_APPS = [
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    'bootstrapform',
    'corsheaders',
    'auditlog',
    'captcha',
    'rest_framework_jwt',
    'django_logtail',
    'app.core',
    'app.support',
    'app.review',
    'app.distribute',
    'app.maintain',
    'app.domain',
    'app.custom',
    'app.mailbox',
    'app.perm',
    'app.maillist',
    'app.group',
    'app.dpt',
    'app.rpt',
    'app.setting',
    'app.security',
]

MIDDLEWARE = [
    'django.middleware.security.SecurityMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.locale.LocaleMiddleware',
    'corsheaders.middleware.CorsMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'app.utils.middleware.login.LoginCsrfMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
    'app.utils.middleware.xforwardedfor.XForwardedForMiddleware',
    'app.utils.middleware.permissions.PermissionsMiddleware',
    'app.utils.middleware.domain.DomainMiddleware',
    'app.utils.middleware.dept.DepartmentMiddleware',
    'auditlog.middleware.AuditlogMiddleware',
]
# 跨域问题，跨域设置为False
# 跨域白名单，维护OA一键登录的时候最好设置CORS_ORIGIN_ALLOW_ALL = False， 此项填写客户的OA域名
CORS_ORIGIN_ALLOW_ALL = False
# CORS_ORIGIN_ALLOW_ALL = False
# CORS_ORIGIN_WHITELIST = (
#     '192.168.1.24:5557',
#     '192.168.1.24:5556',
#     # 'localhost:8000',
#     # '127.0.0.1:9000',
#     # 'google.com',
#     # 'hostname.example.com',
# )

# CORS_ORIGIN_WHITELIST = ( 'www.baidu.com', )
# 支持FRAME, OA嵌套使用，建议默认关闭
XFRAME_OPTIONS_EXEMPT = False

# CSRF Cookie(s) with timeout
CSRF_COOKIE_AGE = 60 * 60
# CSRF Cookie(s) with Secure flag set, 必须https才能设置
CSRF_COOKIE_SECURE = False
# CSRF Cookie(s) with HttpOnly flag set
CSRF_COOKIE_HTTPONLY = False

ROOT_URLCONF = 'operation.urls'

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [os.path.join(BASE_DIR, 'templates')],
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
            ],
        },
    },
]

WSGI_APPLICATION = 'operation.wsgi.application'


# Database
# https://docs.djangoproject.com/en/1.11/ref/settings/#databases

def get_mysql_password():
    import base64
    from ConfigParser import ConfigParser
    from lib.xxtea import decrypt
    cfg = ConfigParser()
    cfg.read('/usr/local/u-mail/config/custom.conf')
    if cfg.has_option('mysql', 'pass_security'):
        passwd = cfg.get('mysql', 'pass_security')
        passwd = decrypt(base64.b32decode(passwd), "umailxxtea16byteslong")
    else:
        passwd = cfg.get('mysql', 'pass')
    return passwd
DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.mysql',     # Add 'postgresql_psycopg2', 'postgresql', 'mysql', 'sqlite3' or 'oracle'.
        'NAME': '{MYSQL_DBNAME}',                    # Or path to database file if using sqlite3.
        'USER': '{MYSQL_USER}',                      # Not used with sqlite3.

        'PASSWORD': get_mysql_password(),                  # Not used with sqlite3.
        'HOST': '{MYSQL_HOST}',                      # Set to empty string for localhost. Not used with sqlite3.
        'PORT': '{MYSQL_PORT}',                      # Set to empty string for default. Not used with sqlite3.
    },
}



# CACHES
CACHES = {
    "default": {
        "BACKEND": "django_redis.cache.RedisCache",
        #"LOCATION": "redis://:PASSWORD@127.0.0.1:6379", #if need password
        "LOCATION": "redis://redis:6379",
        "OPTIONS": {
            "CLIENT_CLASS": "django_redis.client.DefaultClient",
        }
    }
}

# Name of cache backend to cache user agents. If it not specified default
# cache alias will be used. Set to `None` to disable caching.
USER_AGENTS_CACHE = 'default'



# Password validation
# https://docs.djangoproject.com/en/1.11/ref/settings/#auth-password-validators

AUTH_PASSWORD_VALIDATORS = [
    {
        'NAME': 'django.contrib.auth.password_validation.UserAttributeSimilarityValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.MinimumLengthValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.CommonPasswordValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.NumericPasswordValidator',
    },
]


# Internationalization
# https://docs.djangoproject.com/en/1.11/topics/i18n/

TIME_ZONE = 'Asia/Shanghai'

USE_I18N = True

USE_L10N = True

USE_TZ = False

# 验证模块
AUTH_USER_MODEL = 'core.Mailbox'
AUTHENTICATION_BACKENDS = (
    # 'django.contrib.auth.backends.ModelBackend',
    "app.utils.djang_php_bridge.backends.CustomerUserBackend",
)
# php 和django  session登录设置
# SESSION_ENGINE = 'app.utils.djang_php_bridge.db'
# SESSION_COOKIE_NAME = 'PHPSESSID'
# SESSION_ENGINE="django.contrib.sessions.backends.cache"


#USE_X_FORWARDED_HOST = True
#FORCE_SCRIPT_NAME = '/operation'
LOGIN_URL = '/operation/login'
LOGIN_REDIRECT_URL = '/operation'


# Static files (CSS, JavaScript, Images)
# https://docs.djangoproject.com/en/1.11/howto/static-files/

STATIC_URL = '/static/'
STATICFILES_DIRS = (
    os.path.join(BASE_DIR, 'static'),
)

# 邮件缓存目录
UAMIL_CACHE_EMAIL_DIR = "/usr/local/u-mail/data/www/webmail/mailcache"

# ---------------------------
# Celery settings
CELERY_BROKER_URL = 'redis://localhost:6379/0'
#: Only add pickle to this list if your broker is secured
#: from unwanted access (see userguide/security.html)
CELERY_ACCEPT_CONTENT = ["json"]            # 指定任务接受的内容类型.
# CELERY_RESULT_BACKEND = 'redis://localhost:6379/0'
# CELERY_TASK_SERIALIZER = 'json'
# CELERY_TASK_RESULT_EXPIRES = 60 * 5 * 1   # 指定任务过期时间 1小时
CELERY_ENABLE_UTC = True
CELERY_TIMEZONE = TIME_ZONE
CELERY_DEFAULT_QUEUE =  'linux-operation-celery-default' #  默认队列
# ---------------------------


# -------------------------------
# 是否是旧版WEBMAIL
OLD_WEBMAIL_VERSION = False
# -------------------------------

LANGUAGE_COOKIE_NAME = "webvue_language"
LANGUAGE_SESSION_KEY = "_language"
LANGUAGE_CODE = 'zh-hans'
LANGUAGES = (
    ('en', ('English')),
    ('zh-hans', ('中文简体')),
)

#翻译文件所在目录，需要手工创建
LOCALE_PATHS = (
    os.path.join(BASE_DIR, 'locale'),
)

TEMPLATE_CONTEXT_PROCESSORS = (
    "django.core.context_processors.i18n",
)

# 允许的上传文件数
DATA_UPLOAD_MAX_NUMBER_FIELDS = 4096

# session 设置
SESSION_COOKIE_AGE = 60 * 60 # 管理员登陆超时时间
SESSION_SAVE_EVERY_REQUEST = True
SESSION_EXPIRE_AT_BROWSER_CLOSE = False # 关闭浏览器，则COOKIE失效

# 设置 captcha 图片大小
CAPTCHA_IMAGE_SIZE = (80, 45)
# 字符个数
CAPTCHA_LENGTH = 4
# 超时(minutes)
CAPTCHA_TIMEOUT = 24 * 60
# 背景无噪点
CAPTCHA_NOISE_FUNCTIONS = ('captcha.helpers.noise_null', )
# 数字表达式，如2+2=
CAPTCHA_CHALLENGE_FUNCT = 'captcha.helpers.math_challenge'
# 文字颜色
CAPTCHA_FOREGROUND_COLOR = 'green'

DATA_UPLOAD_MAX_MEMORY_SIZE = 10*1024*1024  #默认设置为10M

# 等保专用，隐藏 邮箱账号管理 添加用户 用户信息 部分值为False , 正常情况下应该为True
HTML_ADD_ACCOUNT_PROFILE_SHOW = True
