#!/bin/bash
log() {
	local type="$1"; shift
	printf '%s [%s] [Entrypoint]: %s\n' "$(date --rfc-3339=seconds)" "$type" "$*"
}
note() {
	log Note "$@"
}
warn() {
	log Warn "$@" >&2
}
error() {
	log ERROR "$@" >&2
	exit 1
}

docker_process_init_conf() {
  groupadd -g 9001 umail_apache && useradd -g 9001 -u 9001 umail_apache
  mkdir -p /usr/local/u-mail/app/engine/
  ln -sf /usr/local/bin/ /usr/local/u-mail/app/engine/bin

  if [ ! -f /usr/local/u-mail/config/operation/settings.py ]; then
    log "init operation conf."
    /usr/local/u-mail/app/sbin/confbuilder operation
  fi 


  if [ ! -f /usr/local/u-mail/config/webvue/settings.py ]; then
    log "init webvue conf."
    /usr/local/u-mail/app/sbin/confbuilder webvue
  fi 

  if [ ! -f /usr/local/u-mail/config/webcal/settings.py ]; then
    log "init webcal conf."
    /usr/local/u-mail/app/sbin/confbuilder webcal
  fi 

  if [ ! -d /usr/local/u-mail/config/postfix ]; then
    log "init postfix conf."
    /usr/local/u-mail/app/sbin/confbuilder postfix
  fi

  if [ ! -d /usr/local/u-mail/config/dovecot ]; then
    log "init dovecot conf."
    /usr/local/u-mail/app/sbin/confbuilder dovecot
  fi

  if [ ! -f /usr/local/u-mail/config/nginx/nginx.conf ]; then
    log "init nginx conf."
    /usr/local/u-mail/app/sbin/confbuilder nginx
  fi

  chown -R umail:umail /usr/local/u-mail/app/log
  chown -R umail:umail /usr/local/u-mail/app/run

  ln -sf  /usr/local/u-mail/config/template/app /usr/local/u-mail/app/conf
  ln -sf /usr/local/u-mail/app/conf/supervisord.ini /etc/supervisord.conf

  # app中需要doveamd来重新生成索引
  mv /etc/dovecot/ /etc/dovecot_bak/
  cp -rf /usr/local/u-mail/config/dovecot /etc/dovecot
  cp -f /etc/dovecot/dovecot_app.conf /etc/dovecot/dovecot.conf

  mkdir -p /usr/local/u-mail/service/dovecot/bin/
  ln -sf /usr/bin/doveadm /usr/local/u-mail/service/dovecot/bin/doveadm

  perl -p -i -e "s/127\.0\.0\.1/dspam/gi;" "/usr/local/u-mail/spam-filter/step.py"
}

docker_process_init_conf
