/*
    当需要对某些已存在的表进行列修改时，将ALTER TABLE 语句写在这里。

    这个文件执行时不允许有任何报错，否则不给继续更新。
    所有添加和删除列，需要参考以下代码写存储过程。
    不允许在未判断是否列已经存在的情况下执行ADD 和 DROP 语句！

对于 ALTER TABLE modify 语句，当某一列出现了重复修改时，注释掉旧列，然后执行新列
比如：
-- v2.2.41
-- ALTER TABLE `proxy_account` modify `mailbox` VARCHAR(100) NOT NULL COMMENT '邮箱全名';
ALTER TABLE `proxy_account` modify `mailbox` VARCHAR(200) NOT NULL COMMENT '邮箱全名';

举例：
    --添加列
  drop PROCEDURE if EXISTS add_col_proxy;
  DELIMITER $$
  create procedure add_col_proxy()
  BEGIN
          IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='proxy_server_status' AND COLUMN_NAME='server_name')
          THEN
          ALTER TABLE `proxy_server_status` ADD COLUMN `server_name` varchar(120) NOT NULL COMMENT '用户输入的服务器名称' AFTER `server_num`;
          ALTER TABLE `proxy_server_status` ADD COLUMN `server_ip` varchar(20) NOT NULL COMMENT '服务器IP' AFTER `server_name`;
          END IF;
  END $$
  DELIMITER ;
  call add_col_proxy();
  drop PROCEDURE if EXISTS add_col_proxy;
*/


USE umail;

-- 2.2.47 2017-12-08 修改几个log引擎，避免MyISAM高概率损坏的问题，修改引擎需要放在最前面，因为可能有些表已经坏了
drop PROCEDURE if EXISTS mdf_engine_base;
DELIMITER $$
create procedure mdf_engine_base()
BEGIN
        IF NOT EXISTS (SELECT ENGINE FROM information_schema.TABLES WHERE `TABLE_NAME`='core_mail_log' AND `ENGINE`='InnoDB')
        THEN
            REPAIR TABLE `core_mail_log`;
            ALTER TABLE `core_mail_log` ENGINE=InnoDB;
        END IF;
END $$
DELIMITER ;
call mdf_engine_base();
drop PROCEDURE if EXISTS mdf_engine_base;

drop PROCEDURE if EXISTS mdf_engine_base;
DELIMITER $$
create procedure mdf_engine_base()
BEGIN
        IF NOT EXISTS (SELECT ENGINE FROM information_schema.TABLES WHERE `TABLE_NAME`='core_auth_log' AND `ENGINE`='InnoDB')
        THEN
            REPAIR TABLE `core_auth_log`;
            ALTER TABLE `core_auth_log` ENGINE=InnoDB;
        END IF;
END $$
DELIMITER ;
call mdf_engine_base();
drop PROCEDURE if EXISTS mdf_engine_base;

drop PROCEDURE if EXISTS mdf_engine_base;
DELIMITER $$
create procedure mdf_engine_base()
BEGIN
        IF NOT EXISTS (SELECT ENGINE FROM information_schema.TABLES WHERE `TABLE_NAME`='co_user_log' AND `ENGINE`='InnoDB')
        THEN
            REPAIR TABLE `co_user_log`;
            ALTER TABLE `co_user_log` ENGINE=InnoDB;
        END IF;
END $$
DELIMITER ;
call mdf_engine_base();
drop PROCEDURE if EXISTS mdf_engine_base;
-- 2.2.47 2017-12-08 修改几个引擎 完毕

-- 2.2.61 2018-11-30 修改ext_sequester_mail和ext_imapmail的引擎，这几个表在客户机器上都坏过
drop PROCEDURE if EXISTS mdf_engine_base;
DELIMITER $$
create procedure mdf_engine_base()
BEGIN
        IF NOT EXISTS (SELECT ENGINE FROM information_schema.TABLES WHERE `TABLE_NAME`='ext_sequester_mail' AND `ENGINE`='InnoDB')
        THEN
            REPAIR TABLE `ext_sequester_mail`;
            ALTER TABLE `ext_sequester_mail` ENGINE=InnoDB;
        END IF;
END $$
DELIMITER ;
call mdf_engine_base();
drop PROCEDURE if EXISTS mdf_engine_base;

drop PROCEDURE if EXISTS mdf_engine_base;
DELIMITER $$
create procedure mdf_engine_base()
BEGIN
        IF NOT EXISTS (SELECT ENGINE FROM information_schema.TABLES WHERE `TABLE_NAME`='ext_imapmail' AND `ENGINE`='InnoDB')
        THEN
            REPAIR TABLE `ext_imapmail`;
            ALTER TABLE `ext_imapmail` ENGINE=InnoDB;
        END IF;
END $$
DELIMITER ;
call mdf_engine_base();
drop PROCEDURE if EXISTS mdf_engine_base;
-- 2.2.61 2018-11-30 修改ext_sequester_mail和ext_imapmail的引擎 end

-- 2.2.46 2017-11-09 兼容旧版本webmail一些高概率死锁字段
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='core_mailbox' AND COLUMN_NAME='enable_share')
        THEN
        ALTER TABLE `core_mailbox` ADD COLUMN `enable_share` tinyint(4) NOT NULL DEFAULT '-1';
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;
-- 2.2.46 2017-11-09 兼容旧版本webmail一些高概率死锁字段 end


-- 2.2.41 2017-08-24
drop PROCEDURE if EXISTS mdf_col_base;
DELIMITER $$
create procedure mdf_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='core_mailbox' AND COLUMN_NAME = 'mailbox' AND COLUMN_TYPE='varchar(200)')
        THEN
        ALTER TABLE `core_mailbox` modify `mailbox` VARCHAR(200) NOT NULL COMMENT '邮箱全名';
        ALTER TABLE `core_alias` modify `source` VARCHAR(200) DEFAULT NULL COMMENT '邮箱全名';
        ALTER TABLE `ext_list` modify `address` VARCHAR(200) DEFAULT NULL COMMENT '邮箱全名';
        ALTER TABLE `ext_forward` modify `mailbox` VARCHAR(200) DEFAULT NULL COMMENT '邮箱全名';
        END IF;
END $$
DELIMITER ;
call mdf_col_base();
drop PROCEDURE if EXISTS mdf_col_base;

-- 2.2.41 create idx start
drop PROCEDURE if EXISTS add_col_index;
DELIMITER $$
create procedure add_col_index()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.STATISTICS WHERE TABLE_SCHEMA='umail' AND table_name='core_mailbox' AND INDEX_NAME='mailbox_unique')
        THEN
        CREATE UNIQUE INDEX mailbox_unique ON `core_mailbox` (`mailbox`);
        END IF;
END $$
DELIMITER ;
call add_col_index();
drop PROCEDURE if EXISTS add_col_index;
-- 2.2.41 create idx end

-- 2.2.41 2017-09-05


-- 2.2.42 2017-09-11
--  兼容webmail 1.6.60 - 1.6.64几个版本必定发生死锁的更新
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='core_mailbox' AND COLUMN_NAME='pwd_days')
        THEN
        ALTER TABLE `core_mailbox` ADD COLUMN `pwd_days` int(10) NOT NULL DEFAULT '0' COMMENT '密码有效天数';
        ALTER TABLE `core_mailbox` ADD COLUMN `pwd_days_time` int(11) NOT NULL DEFAULT '0' COMMENT '密码开始时间戳';
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;
-- 兼容 end

-- 2.2.42 2017-09-11


-- 2.2.42 2017-09-11 start
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='admin' AND COLUMN_NAME='is_active')
        THEN
        ALTER TABLE `admin` ADD `is_active` tinyint(1) NOT NULL DEFAULT '1';
        ALTER TABLE `admin` ADD `is_staff` tinyint(1) NOT NULL DEFAULT '1';
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;

-- 2.2.42 2017-09-11 end


-- 2.2.44 2017-10-13 start
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='wm_netdisk_files' AND COLUMN_NAME='share_code')
        THEN
        ALTER TABLE `wm_netdisk_files` ADD `share_code` varchar(100) DEFAULT NULL COMMENT '下载的验证码';
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;

-- 2.2.44 2017-10-13 end

-- 2.2.45 2017-10-30 start
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='core_mail_log' AND COLUMN_NAME='recv_time')
        THEN
        ALTER TABLE `core_mail_log` ADD `recv_time` datetime DEFAULT NULL COMMENT '服务器接收的时间';
        CREATE INDEX recv_time ON `core_mail_log` (`recv_time`);
        UPDATE `core_mail_log` c1 SET c1.`recv_time`=c1.`send_time` WHERE c1.`recv_time` IS NULL;
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;

-- 2.2.45 2017-10-30 end

-- 2.2.46 2017-11-09 start
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='ext_review_new_rule' AND COLUMN_NAME='cond_logic')
        THEN
        ALTER TABLE `ext_review_new_rule` ADD `cond_logic` varchar(20) DEFAULT "all" COMMENT '逻辑表达式 all one';
        UPDATE `ext_review_new_rule` c1 SET c1.`cond_logic`='all' WHERE c1.`cond_logic` IS NULL;
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;
-- 2.2.46 2017-11-09 end

-- 2.2.46 2017-11-10 start
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='core_whitelist' AND COLUMN_NAME='version')
        THEN
        ALTER TABLE `core_whitelist` ADD `version` tinyint(1) NOT NULL DEFAULT '1' COMMENT '将白名单区分为发件人和收件人后用于兼容旧数据的标记值';
        UPDATE `core_whitelist` c1 SET c1.`type`='send' WHERE c1.`type`='recv' AND `mailbox_id`=0;
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;
-- 2.2.46 2017-11-10 end

-- 2.2.46 2017-11-13 start
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='ext_list_member' AND COLUMN_NAME='name')
        THEN
        ALTER TABLE `ext_list_member` ADD `name` VARCHAR(200) NOT NULL DEFAULT '' COMMENT 'win版本导入过来的昵称';
        ALTER TABLE `ext_list_member` ADD `update_time` INT(11) NOT NULL DEFAULT 0 COMMENT '修改时间';
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;
-- 2.2.46 2017-11-13 end

-- 2.2.47 2017-11-16 start
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='ext_review_new_process' AND COLUMN_NAME='reason')
        THEN
        ALTER TABLE `ext_review_new_process` ADD `reason` text COMMENT '修改status的原因';
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;
-- 2.2.47 2017-11-16 end

-- 2.2.47 2017-11-17 start
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='wm_netdisk_files' AND COLUMN_NAME='online_attach_time')
        THEN
        ALTER TABLE `wm_netdisk_files` ADD `online_attach_time` int(11) NOT NULL DEFAULT '0' COMMENT '在线附件转存时间，后期可根据这个字段自动清理网盘';
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;

-- 2.2.47 2017-11-17
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='ext_review_mail' AND COLUMN_NAME='review_time')
        THEN
        ALTER TABLE `ext_review_mail` ADD `review_time` datetime DEFAULT NULL COMMENT '审核操作的时间';
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;
-- 2.2.47 2017-11-17 end

-- 2.2.47 2017-11-20
drop PROCEDURE if EXISTS mdf_col_base;
DELIMITER $$
create procedure mdf_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='ext_sequester_mail' AND COLUMN_NAME = 'subject' AND COLUMN_TYPE='varchar(300)')
        THEN
        ALTER TABLE `ext_sequester_mail` modify `status` enum('wait','permit','whitelist','whitelist2','reject','stop','pass') NOT NULL DEFAULT 'wait' COMMENT '隔离状态';
        ALTER TABLE `ext_sequester_mail` modify `subject` varchar(300) DEFAULT NULL COMMENT '隔离邮件主题,长于300字符的就截断';
        END IF;
END $$
DELIMITER ;
call mdf_col_base();
drop PROCEDURE if EXISTS mdf_col_base;
-- 2.2.47 2017-11-20 end

-- 2.2.47 2017-11-21
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='core_mail_list' AND COLUMN_NAME='folder')
        THEN
        ALTER TABLE `core_mail_list` ADD `folder` varchar(200) NOT NULL DEFAULT 'inbox' COMMENT '存储的文件夹';
        ALTER TABLE `core_mail_list` ADD `uid` INT(11) NOT NULL DEFAULT 0 COMMENT '邮件主键';

        CREATE INDEX msgno ON `core_mail_list` (`msgno`);
        CREATE INDEX uid ON `core_mail_list` (`uid`);
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;
-- 2.2.47 2017-11-21 end

-- 2.2.47 2017-11-22 用于django建立数据库model
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='core_domain_attr' AND COLUMN_NAME='id')
        THEN
        ALTER TABLE `core_domain_attr` ADD `id` int(11) NOT NULL auto_increment FIRST, ADD primary key(id);
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;
-- 2.2.47 2017-11-22 end

-- 2.2.47 2017-11-30 自动回复拓展
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='ext_reply' AND COLUMN_NAME='rule_id')
        THEN
        ALTER TABLE `ext_reply` ADD `rule_id` int(11) NOT NULL DEFAULT '0' COMMENT 'ext_common_checkrule的主键ID';
        ALTER TABLE `ext_reply` ADD `sequence` int(6) NOT NULL DEFAULT 999 COMMENT '数值越小优先级越高,数值相等时主键越小优先级越高' AFTER `rule_id`;

        ALTER TABLE `ext_reply` MODIFY `address` VARCHAR(200) DEFAULT NULL COMMENT '邮箱全名';
        ALTER TABLE `ext_reply` MODIFY `work_mode` enum('full','limit') NOT NULL DEFAULT 'full' COMMENT 'app 2.2.47后废弃';
        ALTER TABLE `ext_reply` MODIFY `work_start` datetime DEFAULT NULL COMMENT 'app 2.2.47后废弃';
        ALTER TABLE `ext_reply` MODIFY `work_end` datetime DEFAULT NULL COMMENT 'app 2.2.47后废弃';
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;

-- 2.2.47 2017-11-30 自动转发拓展
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='ext_forward' AND COLUMN_NAME='rule_id')
        THEN
        ALTER TABLE `ext_forward` ADD `rule_id` int(11) NOT NULL DEFAULT '0' COMMENT 'ext_common_checkrule的主键ID' AFTER `mailbox`;
        ALTER TABLE `ext_forward` ADD `sequence` int(6) NOT NULL DEFAULT 999 COMMENT '数值越小优先级越高,数值相等时主键越小优先级越高' AFTER `rule_id`;
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;
-- 2.2.47 2017-11-30 end

-- 2.2.49 2018-01-04 登录限制拓展
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='core_mailbox' AND COLUMN_NAME='limit_login')
        THEN
        ALTER TABLE `core_mailbox` ADD `limit_login` char(2) NOT NULL DEFAULT '-1' COMMENT '1:只允许客户端登录,-1:不限制';
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;
-- 2.2.49 2018-01-04 end

-- 2.2.49 2018-01-17 邮箱监控拓展
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='core_bcc' AND COLUMN_NAME='target_dept')
        THEN
        ALTER TABLE `core_bcc` ADD `target_dept` int(11) NOT NULL DEFAULT '0' COMMENT '监控部门' AFTER `target`;
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='core_bcc' AND COLUMN_NAME='monit_move')
        THEN
        ALTER TABLE `core_bcc` ADD `monit_move` varchar(10) NOT NULL DEFAULT '-1' COMMENT '1：监控邮箱搬家,-1:不监控' AFTER `target_dept`;
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;
-- 2.2.49 2018-01-17 end

-- 2.2.50 2018-01-26 用于webmail登录界面的拓展
drop PROCEDURE if EXISTS add_data_base;
DELIMITER $$
create procedure add_data_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM umail.core_domain_login_temp WHERE `code`='center')
        THEN
            INSERT INTO `core_domain_login_temp` ( `code`, `temp_name`, `add_time`, `update_time`, `folder`, `src`, `type`)
            VALUES('center','登录框居中登录页面','1516936979','1516936979','login_center','/webmail/admin/style/img/login_temp6.png','0');
        END IF;
END $$
DELIMITER ;
call add_data_base();
drop PROCEDURE if EXISTS add_data_base;
-- 2.2.50 2018-01-26 end

-- 2.2.50 2018-01-30 popmail拓展
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='ext_popmail' AND COLUMN_NAME='status')
        THEN
            ALTER TABLE `ext_popmail` ADD `status` varchar(20) NOT NULL DEFAULT 'wait' COMMENT 'wait:空闲,moving:迁移中,done:迁移完毕' AFTER `dst_folder`;
            ALTER TABLE `ext_popmail` ADD `desc_msg` text DEFAULT NULL COMMENT '描述，任意阶段，当底层觉得有必要显示提示时，会往这里填充数据' AFTER `status`;
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;
-- 2.2.50 2018-01-30 end

-- 2.2.52 2018-03-02 修改密码长度
drop PROCEDURE if EXISTS mdf_col_base;
DELIMITER $$
create procedure mdf_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='core_mailbox' AND COLUMN_NAME = 'password' AND COLUMN_TYPE='varchar(120)')
        THEN
        ALTER TABLE `admin` modify `password` VARCHAR(120) DEFAULT NULL COMMENT '密码';
        ALTER TABLE `core_mailbox` modify `password` VARCHAR(120) DEFAULT NULL COMMENT '密码';
        END IF;
END $$
DELIMITER ;
call mdf_col_base();
drop PROCEDURE if EXISTS mdf_col_base;
-- 2.2.52 2018-03-02 修改密码长度 end

-- 2.2.52 2018-03-05 smtp外发中转拓展
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='ext_smtp_transfer' AND COLUMN_NAME='fail_report')
        THEN
        ALTER TABLE `ext_smtp_transfer` ADD `mailbox` varchar(200) DEFAULT NULL COMMENT '用户邮箱' AFTER `mailbox_id`;
        ALTER TABLE `ext_smtp_transfer` ADD `fail_report` varchar(200) DEFAULT NULL COMMENT '投递失败后的通知人' AFTER `auth`;
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;
-- 2.2.52 2018-03-05 smtp外发中转拓展 end

-- 2.2.52 2018-03-05 smtp收信中转拓展
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='ext_post_transfer' AND COLUMN_NAME='recipient')
        THEN
        ALTER TABLE `ext_post_transfer` ADD `recipient` varchar(200) DEFAULT NULL  COMMENT '收件帐号' AFTER `account`;
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;
-- 2.2.52 2018-03-05 smtp收信中转拓展 end

-- 2.2.52 2018-03-13 为core_mail_log新增索引 start
drop PROCEDURE if EXISTS add_idx_base;
DELIMITER $$
create procedure add_idx_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.STATISTICS WHERE TABLE_SCHEMA='umail' AND table_name='core_mail_log' AND index_name = 'status')
        THEN
        CREATE INDEX status ON `core_mail_log` (`status`);
        END IF;
END $$
DELIMITER ;
call add_idx_base();
drop PROCEDURE if EXISTS add_idx_base;

drop PROCEDURE if EXISTS add_idx_base;
DELIMITER $$
create procedure add_idx_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.STATISTICS WHERE TABLE_SCHEMA='umail' AND table_name='core_mail_log' AND index_name = 'time_range')
        THEN
        CREATE INDEX time_range ON `core_mail_log` (`type`,`status`,`recv_time`);
        END IF;
END $$
DELIMITER ;
call add_idx_base();
drop PROCEDURE if EXISTS add_idx_base;

drop PROCEDURE if EXISTS add_idx_base;
DELIMITER $$
create procedure add_idx_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.STATISTICS WHERE TABLE_SCHEMA='umail' AND table_name='core_mail_log' AND index_name = 'size_range')
        THEN
        CREATE INDEX size_range ON `core_mail_log` (`type`,`status`,`size`,`attachment_size`);
        END IF;
END $$
DELIMITER ;
call add_idx_base();
drop PROCEDURE if EXISTS add_idx_base;

drop PROCEDURE if EXISTS add_idx_base;
DELIMITER $$
create procedure add_idx_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.STATISTICS WHERE TABLE_SCHEMA='umail' AND table_name='core_mail_log' AND index_name = 'mailbox_range')
        THEN
        CREATE INDEX mailbox_range ON `core_mail_log` (`type`,`status`,`send_mail`,`rcv_mail`);
        END IF;
END $$
DELIMITER ;
call add_idx_base();
drop PROCEDURE if EXISTS add_idx_base;
-- 2.2.52 2018-03-13 为core_mail_log新增索引 end

-- 2.2.52 2018-03-13 用于webmail登录界面的拓展
drop PROCEDURE if EXISTS add_data_base;
DELIMITER $$
create procedure add_data_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM umail.core_domain_login_temp WHERE `code`='sanya')
        THEN
            INSERT INTO `core_domain_login_temp`(`code`,`temp_name`,`add_time`,`update_time`,`folder`,`src`,`type`)
            VALUES ('sanya','背景图风格登录页面',1516936979,1516936979,'login_sanya','/webmail/admin/style/img/login_sanya.png',0);
        END IF;
END $$
DELIMITER ;
call add_data_base();
drop PROCEDURE if EXISTS add_data_base;

-- 2.2.52 2018-03-13 end

-- 2.2.53 2018-03-19
ALTER TABLE `ext_list` MODIFY `permission` enum('public','private','domain','domain2') NOT NULL DEFAULT 'public' COMMENT '权限';
-- 2.2.53 2018-03-19

-- 2.2.53 2018-03-22为 core_mail_log 和 core_auth_log 新增索引
drop PROCEDURE if EXISTS add_idx_base;
DELIMITER $$
create procedure add_idx_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.STATISTICS WHERE TABLE_SCHEMA='umail' AND table_name='core_mail_log' AND index_name = 'domain_type')
        THEN
        CREATE INDEX domain_type ON `core_mail_log` (`type`,`status`,`domain_id`);
        END IF;
END $$
DELIMITER ;
call add_idx_base();
drop PROCEDURE if EXISTS add_idx_base;

drop PROCEDURE if EXISTS add_idx_base;
DELIMITER $$
create procedure add_idx_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.STATISTICS WHERE TABLE_SCHEMA='umail' AND table_name='core_mail_log' AND index_name = 'mailbox_type')
        THEN
        CREATE INDEX mailbox_type ON `core_mail_log` (`type`,`status`,`mailbox_id`);
        END IF;
END $$
DELIMITER ;
call add_idx_base();
drop PROCEDURE if EXISTS add_idx_base;

drop PROCEDURE if EXISTS add_idx_base;
DELIMITER $$
create procedure add_idx_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.STATISTICS WHERE TABLE_SCHEMA='umail' AND table_name='core_mail_log' AND index_name = 'mailbox_id')
        THEN
        CREATE INDEX mailbox_id ON `core_mail_log` (`mailbox_id`);
        END IF;
END $$
DELIMITER ;
call add_idx_base();
drop PROCEDURE if EXISTS add_idx_base;

drop PROCEDURE if EXISTS add_idx_base;
DELIMITER $$
create procedure add_idx_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.STATISTICS WHERE TABLE_SCHEMA='umail' AND table_name='core_auth_log' AND index_name = 'domain_type')
        THEN
        CREATE INDEX domain_type ON `core_auth_log` (`domain_id`,`type`);
        END IF;
END $$
DELIMITER ;
call add_idx_base();
drop PROCEDURE if EXISTS add_idx_base;

drop PROCEDURE if EXISTS add_idx_base;
DELIMITER $$
create procedure add_idx_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.STATISTICS WHERE TABLE_SCHEMA='umail' AND table_name='core_auth_log' AND index_name = 'user')
        THEN
        CREATE INDEX user ON `core_auth_log` (`user`);
        END IF;
END $$
DELIMITER ;
call add_idx_base();
drop PROCEDURE if EXISTS add_idx_base;

drop PROCEDURE if EXISTS add_idx_base;
DELIMITER $$
create procedure add_idx_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.STATISTICS WHERE TABLE_SCHEMA='umail' AND table_name='core_auth_log' AND index_name = 'domain_type')
        THEN
        CREATE INDEX domain_type ON `core_auth_log` (`domain_id`,`type`,`time`);
        END IF;
END $$
DELIMITER ;
call add_idx_base();
drop PROCEDURE if EXISTS add_idx_base;
-- 2.2.53 2018-03-22 end

-- 2.2.54 2018-03-23 用于django建立数据库model
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='co_department_member' AND COLUMN_NAME='id')
        THEN
        ALTER TABLE `co_department_member` ADD `id` int(11) NOT NULL auto_increment FIRST, ADD primary key(id);
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;
-- 2.2.54 2018-03-23 用于django建立数据库model end

-- 2.2.54 2018-03-23 core_mail_log 创建新字段
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='core_mail_log' AND COLUMN_NAME='folder')
        THEN
        ALTER TABLE `core_mail_log` ADD `folder` varchar(100) DEFAULT NULL COMMENT '投递位置';
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='core_mail_log' AND COLUMN_NAME='remark')
        THEN
        ALTER TABLE `core_mail_log` ADD `remark` varchar(1000) DEFAULT NULL COMMENT '提示';
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;
-- 2.2.54 2018-03-23 core_mail_log 创建新字段 end

-- 2.2.54 2018-03-28 core_auth_log 创建新字段
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='core_auth_log' AND COLUMN_NAME='remark')
        THEN
        ALTER TABLE `core_auth_log` ADD `remark` varchar(1000) DEFAULT NULL COMMENT '提示' AFTER `is_login`;
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;
-- 2.2.54 2018-03-28 core_auth_log 创建新字段 end

-- 2.2.54 2018-03-29 core_mail_log
drop PROCEDURE if EXISTS add_idx_base;
DELIMITER $$
create procedure add_idx_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.STATISTICS WHERE TABLE_SCHEMA='umail' AND table_name='core_mail_log' AND index_name = 'domain_type2')
        THEN
        CREATE INDEX domain_type2 ON `core_mail_log` (`domain_id`,`type`,`recv_time`,`mailbox_id`);
        END IF;
END $$
DELIMITER ;
call add_idx_base();
drop PROCEDURE if EXISTS add_idx_base;

drop PROCEDURE if EXISTS add_idx_base;
DELIMITER $$
create procedure add_idx_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.STATISTICS WHERE TABLE_SCHEMA='umail' AND table_name='core_mail_log' AND index_name = 'domain_type3')
        THEN
        CREATE INDEX domain_type3 ON `core_mail_log` (`domain_id`,`recv_time`,`mailbox_id`);
        END IF;
END $$
DELIMITER ;
call add_idx_base();
drop PROCEDURE if EXISTS add_idx_base;
-- 2.2.54 2018-03-29 core_mail_log

-- 2.2.55 2018-04-17 co_user_change 用户审核,webmail使用
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='co_user_change' AND COLUMN_NAME = 'gender')
        THEN
        ALTER TABLE `co_user_change` ADD `gender` ENUM('male','female') NOT NULL DEFAULT 'male';
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;
-- 2.2.55 2018-04-17 co_user_change

-- 2.2.55 2018-04-19 wm_signature 个人签名设置
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='wm_signature' AND COLUMN_NAME = 'type')
        THEN
        ALTER TABLE `wm_signature` ADD `type` varchar(20) NOT NULL DEFAULT 'mailbox' AFTER `mailbox_id`;
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;
-- 2.2.55 2018-04-19 wm_signature 个人签名设置 end

-- 2.2.55 2018-05-09 修改core_domain_attr.value的最大长度，使得域签名能插入更大的图片
drop PROCEDURE if EXISTS mdf_col_base;
DELIMITER $$
create procedure mdf_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='core_domain_attr' AND COLUMN_NAME = 'value' AND DATA_TYPE = 'mediumtext')
        THEN
        ALTER TABLE `core_domain_attr` modify `value` mediumtext;
        END IF;
END $$
DELIMITER ;
call mdf_col_base();
drop PROCEDURE if EXISTS mdf_col_base;
-- 2.2.55 2018-05-09 修改core_domain_attr.value的最大长度 end

-- 2.2.55 2018-04-19 ext_fail2ban_block新增协议列
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='ext_fail2ban_block' AND COLUMN_NAME = 'proto')
        THEN
        ALTER TABLE `ext_fail2ban_block` ADD `proto` varchar(50) NOT NULL DEFAULT 'ALL' COMMENT '邮件协议' AFTER `ip`;
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;
-- 2.2.55 2018-04-19 ext_fail2ban_block新增协议列 end

-- 2.2.55 2018-06-04 ext_secret_mail新增主键
drop PROCEDURE if EXISTS mdf_col_base;
DELIMITER $$
create procedure mdf_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='ext_secret_mail' AND COLUMN_NAME = 'id' AND COLUMN_KEY = 'PRI')
        THEN
        ALTER TABLE `ext_secret_mail` modify `id` int(11) NOT NULL auto_increment FIRST, ADD primary key(id);
        END IF;
END $$
DELIMITER ;
call mdf_col_base();
drop PROCEDURE if EXISTS mdf_col_base;
-- 2.2.55 2018-06-04 ext_secret_mail新增主键

-- 2.2.55 2018-06-08 发件人和收件人白名单继续区分出"指定外域"类型
drop PROCEDURE if EXISTS mdf_col_base;
DELIMITER $$
create procedure mdf_col_base()
BEGIN
        IF EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='core_whitelist' AND COLUMN_NAME = 'type' AND DATA_TYPE = 'enum')
        THEN
        ALTER TABLE `core_whitelist` modify `type` varchar(20) NOT NULL DEFAULT 'recv' COMMENT '类型 recv:收件人白名单,send:发件人白名单,fix_send:指定外域发件白名单,fix_recv:指定外域收件白名单';
        END IF;
END $$
DELIMITER ;
call mdf_col_base();
drop PROCEDURE if EXISTS mdf_col_base;
-- 2.2.55 2018-06-08 ext_secret_mail新增主键

-- 2.2.55 2018-06-08 core_upgrade_list新增列
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='core_upgrade_list' AND COLUMN_NAME = 'company')
        THEN
        ALTER TABLE `core_upgrade_list` ADD `company` varchar(250) NOT NULL DEFAULT 'Unknown' COMMENT '公司名称' AFTER `id`;
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;
-- 2.2.55 2018-06-08 core_upgrade_list新增列 end

-- 2.2.55 2018-06-12 新增主键
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='co_company' AND COLUMN_NAME = 'id')
        THEN
        ALTER TABLE `co_company` ADD `id` int(11) NOT NULL auto_increment FIRST, ADD primary key(id);
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;

drop PROCEDURE if EXISTS mdf_col_base;
DELIMITER $$
create procedure mdf_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='wx_config' AND COLUMN_NAME = 'id' AND EXTRA='auto_increment')
        THEN
        ALTER TABLE `wx_config` MODIFY `id` int(11) NOT NULL auto_increment FIRST;
        END IF;
END $$
DELIMITER ;
call mdf_col_base();
drop PROCEDURE if EXISTS mdf_col_base;
-- 2.2.55 2018-06-12 新增主键

-- 2.2.55 2018-06-08 ext_ldap_list新增列
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='ext_ldap_list' AND COLUMN_NAME = 'priority')
        THEN
        ALTER TABLE `ext_ldap_list` ADD `priority` int(11) NOT NULL DEFAULT '999' COMMENT '优先级,数值越小优先级越高' AFTER `id`;
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;
-- 2.2.55 2018-06-08 ext_ldap_list新增列 end

-- 2.2.56 2018-07-25 超级管理后台拓展的一些数据库列
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='core_mailbox' AND COLUMN_NAME = 'email')
        THEN
            ALTER TABLE `core_mailbox` ADD `last_login` DATETIME NULL DEFAULT NULL COMMENT '最后登录时间' ;
            ALTER TABLE `core_mailbox` ADD `is_active` TINYINT(1) NOT NULL DEFAULT '0' COMMENT '是否是管理员';
            ALTER TABLE `core_mailbox` ADD `is_staff` TINYINT(1) NOT NULL DEFAULT '0' COMMENT '是否是员工';
            ALTER TABLE `core_mailbox` ADD `is_superuser` TINYINT(1) NOT NULL DEFAULT '0' COMMENT '超级用户';
            ALTER TABLE `core_mailbox` ADD `first_name` VARCHAR(30) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL;
            ALTER TABLE `core_mailbox` ADD `last_name` VARCHAR(30) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL;
            ALTER TABLE `core_mailbox` ADD `date_joined` DATETIME DEFAULT NULL;
            ALTER TABLE `core_mailbox` ADD `email` VARCHAR(150) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL;

            ALTER TABLE `core_mailbox` MODIFY `limit_pop` enum('-1','1') NOT NULL DEFAULT '-1' COMMENT '>=2.2.58后废弃，与组权限冲突';
            ALTER TABLE `core_mailbox` MODIFY `limit_imap` enum('-1','1') NOT NULL DEFAULT '-1' COMMENT '>=2.2.58后废弃，与组权限冲突';
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;

drop PROCEDURE if EXISTS mdf_col_base;
DELIMITER $$
create procedure mdf_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='auditlog_logentry' AND COLUMN_NAME = 'extend_content' AND CHARACTER_SET_NAME='utf8')
        THEN
            ALTER TABLE `auditlog_logentry` CHANGE `object_pk` `object_pk` VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL;
            ALTER TABLE `auditlog_logentry` CHANGE `object_repr` `object_repr` longtext CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL;
            ALTER TABLE `auditlog_logentry` CHANGE `changes` `changes` longtext CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL;
            ALTER TABLE `auditlog_logentry` CHANGE `remote_addr` `remote_addr` VARCHAR(39) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL;
            ALTER TABLE `auditlog_logentry` CHANGE `additional_data` `additional_data` longtext CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL;
            ALTER TABLE `auditlog_logentry` CHANGE `extend_type` `extend_type` VARCHAR(50) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL;
            ALTER TABLE `auditlog_logentry` CHANGE `extend_content` `extend_content` longtext CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL;
        END IF;
END $$
DELIMITER ;
call mdf_col_base();
drop PROCEDURE if EXISTS mdf_col_base;

drop PROCEDURE if EXISTS mdf_col_base;
DELIMITER $$
create procedure mdf_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='auth_permission' AND COLUMN_NAME = 'name' AND CHARACTER_SET_NAME='utf8')
        THEN
            ALTER TABLE `auth_permission` CHANGE `name` `name` VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL;
        END IF;
END $$
DELIMITER ;
call mdf_col_base();
drop PROCEDURE if EXISTS mdf_col_base;

drop PROCEDURE if EXISTS add_idx_base;
DELIMITER $$
create procedure add_idx_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.STATISTICS WHERE TABLE_SCHEMA='umail' AND table_name='co_department' AND index_name = 'showorder')
        THEN
            ALTER TABLE `co_department` ADD INDEX(`showorder`);
        END IF;
END $$
DELIMITER ;
call add_idx_base();
drop PROCEDURE if EXISTS add_idx_base;

drop PROCEDURE if EXISTS mdf_col_base;
DELIMITER $$
create procedure mdf_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='oab_share' AND COLUMN_NAME = 'id')
        THEN
            ALTER TABLE `oab_share` ADD `id` INT(11) NOT NULL AUTO_INCREMENT PRIMARY KEY FIRST;
        END IF;
END $$
DELIMITER ;
call mdf_col_base();
drop PROCEDURE if EXISTS mdf_col_base;

drop PROCEDURE if EXISTS mdf_col_base;
DELIMITER $$
create procedure mdf_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='core_blacklist' AND COLUMN_NAME = 'remark')
        THEN
            ALTER TABLE `core_blacklist` ADD `remark` TEXT CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '备注' ;
        END IF;
END $$
DELIMITER ;
call mdf_col_base();
drop PROCEDURE if EXISTS mdf_col_base;

drop PROCEDURE if EXISTS mdf_col_base;
DELIMITER $$
create procedure mdf_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='core_whitelist' AND COLUMN_NAME = 'remark')
        THEN
            ALTER TABLE `core_whitelist` ADD `remark` TEXT CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '备注' ;
        END IF;
END $$
DELIMITER ;
call mdf_col_base();
drop PROCEDURE if EXISTS mdf_col_base;

drop PROCEDURE if EXISTS mdf_col_base;
DELIMITER $$
create procedure mdf_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='auth_group' AND COLUMN_NAME = 'name' AND CHARACTER_SET_NAME='utf8')
        THEN
            -- 管理员管理
            ALTER TABLE `auth_group` CHANGE `name` `name` VARCHAR(80) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL;
        END IF;
END $$
DELIMITER ;
call mdf_col_base();
drop PROCEDURE if EXISTS mdf_col_base;

-- 2.2.56 2018-07-25 超级管理后台拓展的一些数据库列 end


-- 2.2.56 2018-08-02 给一些旧表补充id主键
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='co_department_info' AND COLUMN_NAME='id')
        THEN
        ALTER TABLE `co_department_info` ADD `id` int(11) NOT NULL auto_increment FIRST, ADD primary key(id);
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='co_group_member' AND COLUMN_NAME='id')
        THEN
        ALTER TABLE `co_group_member` ADD `id` int(11) NOT NULL auto_increment FIRST, ADD primary key(id);
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='co_user_attr' AND COLUMN_NAME='id')
        THEN
        ALTER TABLE `co_user_attr` ADD `id` int(11) NOT NULL auto_increment FIRST, ADD primary key(id);
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='core_mail_list' AND COLUMN_NAME='id')
        THEN
        ALTER TABLE `core_mail_list` ADD `id` int(11) NOT NULL auto_increment FIRST, ADD primary key(id);
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='oab_share' AND COLUMN_NAME='id')
        THEN
        ALTER TABLE `oab_share` ADD `id` int(11) NOT NULL auto_increment FIRST, ADD primary key(id);
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='widget_cogroup_member' AND COLUMN_NAME='id')
        THEN
        ALTER TABLE `widget_cogroup_member` ADD `id` int(11) NOT NULL auto_increment FIRST, ADD primary key(id);
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='widget_score_stat' AND COLUMN_NAME='id')
        THEN
        ALTER TABLE `widget_score_stat` ADD `id` int(11) NOT NULL auto_increment FIRST, ADD primary key(id);
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='widget_score_type' AND COLUMN_NAME='id')
        THEN
        ALTER TABLE `widget_score_type` ADD `id` int(11) NOT NULL auto_increment FIRST, ADD primary key(id);
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='wm_addrbook_email' AND COLUMN_NAME='id')
        THEN
        ALTER TABLE `wm_addrbook_email` ADD `id` int(11) NOT NULL auto_increment FIRST, ADD primary key(id);
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='wm_addrbook_map' AND COLUMN_NAME='id')
        THEN
        ALTER TABLE `wm_addrbook_map` ADD `id` int(11) NOT NULL auto_increment FIRST, ADD primary key(id);
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='wm_statistics' AND COLUMN_NAME='id')
        THEN
        ALTER TABLE `wm_statistics` ADD `id` int(11) NOT NULL auto_increment FIRST, ADD primary key(id);
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;
-- 2.2.56 2018-08-02 给一些旧表补充id主键 end

-- 2.2.56 2018-08-06 审核条件增加父子条件关系
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='ext_review_new_condition' AND COLUMN_NAME='parent_id')
        THEN
        ALTER TABLE `ext_review_new_condition` ADD `parent_id` int(11) NOT NULL DEFAULT 0 COMMENT '这个条件的父亲ID，逻辑关系由parent_id指向的那一行决定' AFTER `id`;
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='ext_review_new_condition' AND COLUMN_NAME='logic')
        THEN
        ALTER TABLE `ext_review_new_condition` ADD `logic` varchar(20) DEFAULT 'all' COMMENT '逻辑表达式 all one' AFTER `rule_id`;
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;
-- 2.2.56 2018-08-06 审核条件增加父子条件关系

-- 2.2.56 2018-08-15 邮箱删除标记
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='core_mailbox' AND COLUMN_NAME='is_delete')
        THEN
        ALTER TABLE `core_mailbox` ADD COLUMN `is_delete` tinyint(2) NOT NULL DEFAULT '-1' AFTER `disabled`;
        ALTER TABLE `core_mailbox` ADD COLUMN `delete_time` datetime DEFAULT NULL COMMENT '开始删除时间' AFTER `is_delete`;
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;

-- 2.2.56 2018-08-30 内网邮件代发拓展成所有通道
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='ext_post_transfer' AND COLUMN_NAME='type')
        THEN
        ALTER TABLE `ext_post_transfer` ADD COLUMN `type` varchar(20) NOT NULL DEFAULT 'in' COMMENT 'int:内发,out:外发,all:所有' AFTER `mailbox`;
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;
-- 2.2.56 2018-08-30

-- 2.2.57 2018-09-05 黑白名单索引
drop PROCEDURE if EXISTS add_idx_base;
DELIMITER $$
create procedure add_idx_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.STATISTICS WHERE TABLE_SCHEMA='umail' AND table_name='core_whitelist' AND index_name = 'whitelist')
        THEN
            CREATE INDEX whitelist ON `core_whitelist` (`domain_id`, `mailbox_id`, `operator`, `type`);
        END IF;
END $$
DELIMITER ;
call add_idx_base();
drop PROCEDURE if EXISTS add_idx_base;

drop PROCEDURE if EXISTS add_idx_base;
DELIMITER $$
create procedure add_idx_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.STATISTICS WHERE TABLE_SCHEMA='umail' AND table_name='core_blacklist' AND index_name = 'blacklist')
        THEN
            CREATE INDEX blacklist ON `core_blacklist` ( `domain_id`, `mailbox_id`, `operator`, `type`);
        END IF;
END $$
DELIMITER ;
call add_idx_base();
drop PROCEDURE if EXISTS add_idx_base;

drop PROCEDURE if EXISTS add_idx_base;
DELIMITER $$
create procedure add_idx_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.STATISTICS WHERE TABLE_SCHEMA='umail' AND table_name='ext_maillog' AND index_name = 'mailbox_operate')
        THEN
            CREATE INDEX mailbox_operate ON `ext_maillog` ( `domain_id`, `mailbox_id`, `operate` );
        END IF;
END $$
DELIMITER ;
call add_idx_base();
drop PROCEDURE if EXISTS add_idx_base;
-- 2.2.57 2018-09-05 黑白名单索引 end

-- 2.2.57 2018-09-12 网盘索引
drop PROCEDURE if EXISTS add_idx_base;
DELIMITER $$
create procedure add_idx_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.STATISTICS WHERE TABLE_SCHEMA='umail' AND table_name='wm_netdisk_folder' AND index_name = 'parent_index')
        THEN
            CREATE INDEX folder_index ON `wm_netdisk_files` ( `domain_id`, `mailbox_id`, `folder_id`);
            CREATE INDEX parent_index ON `wm_netdisk_folder` ( `domain_id`, `mailbox_id`, `parent_id`);
        END IF;
END $$
DELIMITER ;
call add_idx_base();
drop PROCEDURE if EXISTS add_idx_base;
-- 2.2.57 2018-09-12 网盘索引 end

-- 2.2.58 2018-09-18 日程兼容2016-09缺失的一个字段，那个版本的PHP数据库更新有坑
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='wm_calendar' AND COLUMN_NAME='place')
        THEN
        ALTER TABLE `wm_calendar` ADD `place` VARCHAR(32) NULL DEFAULT NULL AFTER `description`;
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;
-- 2.2.58 2018-09-18 日程兼容 end

-- 2.2.58 2018-09-18 日程数据库更新
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='wm_calendar' AND COLUMN_NAME='remind_measurement')
        THEN
        ALTER TABLE `wm_calendar` ADD `is_remind` TINYINT(2) NOT NULL DEFAULT '0' COMMENT '是否提醒' AFTER `repeat_end`;
        ALTER TABLE `wm_calendar` ADD `remind_detail` INT(8) NOT NULL DEFAULT '0' COMMENT '提前多少单位提醒' AFTER `is_remind`;
        ALTER TABLE `wm_calendar` ADD `remind_measurement` INT(11) NOT NULL DEFAULT '60' COMMENT '提醒提前多少分钟单位' AFTER `remind_detail`;
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;
-- 2.2.58 2018-09-18 日程数据库更新 end

-- 2.2.58 2018-09-18 网盘拓展
drop PROCEDURE if EXISTS mdf_col_base;
DELIMITER $$
create procedure mdf_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='wm_netdisk_files' AND COLUMN_NAME = 'file_type' AND CHARACTER_MAXIMUM_LENGTH=200)
        THEN
            -- 管理员管理
            ALTER TABLE `wm_netdisk_files` CHANGE `file_type` `file_type` VARCHAR(200) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL;
        END IF;
END $$
DELIMITER ;
call mdf_col_base();
drop PROCEDURE if EXISTS mdf_col_base;
-- 2.2.58 2018-09-18 网盘拓展 end

-- 2.2.58 2018-09-19 组权限拓展  通讯录显示控制
drop PROCEDURE if EXISTS add_idx_base;
DELIMITER $$
create procedure add_idx_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.STATISTICS WHERE TABLE_SCHEMA='umail' AND table_name='core_group_member' AND index_name = 'mailbox_id')
        THEN
            CREATE UNIQUE INDEX mailbox_id ON `core_group_member` (`mailbox_id`);
        END IF;
END $$
DELIMITER ;
call add_idx_base();
drop PROCEDURE if EXISTS add_idx_base;
-- 2.2.58 2018-09-19 组权限拓展 end

-- 2.2.59 2018-10-19 内容过滤器拓展
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='ext_cfilter_rule_new' AND COLUMN_NAME='extype')
        THEN
        ALTER TABLE `ext_cfilter_rule_new` ADD `extype` VARCHAR(5) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT 'ot' COMMENT '扩展类型' ;
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;
-- 2.2.59 2018-10-19 内容过滤器拓展 end

-- 2.2.60 2018-11-12 修改坑爹的core_alias的type类型
drop PROCEDURE if EXISTS mdf_col_base;
DELIMITER $$
create procedure mdf_col_base()
BEGIN
        IF EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='core_alias' AND COLUMN_NAME = 'type' AND DATA_TYPE = 'enum')
        THEN
        ALTER TABLE `core_alias` MODIFY `type` varchar(20) NOT NULL DEFAULT 'mailbox' COMMENT '别名类型';
        END IF;
END $$
DELIMITER ;
call mdf_col_base();
drop PROCEDURE if EXISTS mdf_col_base;
-- 2.2.60 2018-11-12 修改坑爹的core_alias的type类型

-- 2.2.61 2018-11-15 新版webmail表拓展
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='co_user' AND COLUMN_NAME='last_ip')
        THEN
        ALTER TABLE `co_user` ADD `last_ip` varchar(20) DEFAULT NULL COMMENT '最后登陆IP';
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;
-- 2.2.60 2018-11-15 co_user表拓展 end

-- 2.2.61 2018-11-15 新版webmail表拓展
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='co_user_change' AND COLUMN_NAME='changes')
        THEN
        ALTER TABLE `co_user_change` ADD `changes` TEXT CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '改变内容' AFTER `gender`;
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;

drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='ext_common_checkrule' AND COLUMN_NAME='sequence')
        THEN
        ALTER TABLE `ext_common_checkrule` ADD `sequence` INT(6) NOT NULL DEFAULT '999' COMMENT '权重' AFTER `disabled`;
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;

drop PROCEDURE if EXISTS add_idx_base;
DELIMITER $$
create procedure add_idx_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.STATISTICS WHERE TABLE_SCHEMA='umail' AND table_name='wm_relate_email' AND index_name = 'mailbox_id')
        THEN
            CREATE INDEX mailbox_id ON `wm_relate_email` (`mailbox_id`);
            CREATE INDEX target_id ON `wm_relate_email` (`target_id`);
            CREATE UNIQUE INDEX target_id2 ON `wm_relate_email` (`domain_id`, `mailbox_id`, `target_id`);
        END IF;
END $$
DELIMITER ;
call add_idx_base();
drop PROCEDURE if EXISTS add_idx_base;
-- 2.2.61 2018-11-15 新版webmail表拓展 end

-- 2.2.60 2018-11-20 给core_alias加唯一约束
drop PROCEDURE if EXISTS add_idx_base;
DELIMITER $$
create procedure add_idx_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.STATISTICS WHERE TABLE_SCHEMA='umail' AND table_name='core_alias' AND index_name = 'source')
        THEN
            CREATE UNIQUE INDEX source ON `core_alias` (`source`);
        END IF;
END $$
DELIMITER ;
call add_idx_base();
drop PROCEDURE if EXISTS add_idx_base;
-- 2.2.60 2018-11-20 给core_alias加唯一约束 end

-- 2.2.60 2018-11-26 指定域收发白名单升级后的数据库设置
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='core_whitelist' AND COLUMN_NAME='version' AND COLUMN_DEFAULT='2')
        THEN
        ALTER TABLE `core_whitelist` MODIFY `version` tinyint(1) NOT NULL DEFAULT '2' COMMENT '将白名单区分为发件人和收件人后用于兼容旧数据的标记值';
        update core_whitelist set type='fix_send' where operator='user' and type='send' and mailbox_id!=0;
        update core_whitelist set type='fix_recv' where operator='user' and type='recv' and mailbox_id!=0;
        update core_whitelist set type='fix_send' where operator='sys' and type='send' and mailbox_id!=0;
        update core_whitelist set type='fix_recv' where operator='sys' and type='recv' and mailbox_id!=0;
        update core_whitelist set type='fix_send' where operator='sys' and type='send' and domain_id!=0 and mailbox_id=0;
        update core_whitelist set type='fix_recv' where operator='sys' and type='recv' and domain_id!=0 and mailbox_id=0;
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;
-- 2.2.60 2018-11-26 指定域收发白名单升级后的数据库设置 end

-- 2.2.61 2018-12-10
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='core_auth_log' AND COLUMN_NAME='browser')
        THEN
        ALTER TABLE `core_auth_log` ADD `browser` VARCHAR(300) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '浏览器';
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;
-- 2.2.61 2018-12-10 end

-- 2.2.61 2018-12-13 组权限重新设计及数据兼容
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='core_group' AND COLUMN_NAME='version')
        THEN
        ALTER TABLE `core_group` ADD `version` varchar(2) DEFAULT '2' COMMENT '组权限版本,主要用来做数据迁移的判定' AFTER `description`;
        -- 将旧版本的数据设置为1,用于数据迁移到 core_group_setting
        UPDATE `core_group` SET `version` = '1';
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;

drop PROCEDURE if EXISTS del_col_base;
DELIMITER $$
create procedure del_col_base()
BEGIN
        -- 删除旧版本的列
        IF EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='core_group' AND COLUMN_NAME='mail_space')
        THEN
            -- version=1 说明数据还没兼容，不能删，=2说明已经兼容
            IF NOT EXISTS (SELECT 1 FROM core_group WHERE `version`=1)
            THEN
                ALTER TABLE `core_group` DROP COLUMN `mail_space`;
                ALTER TABLE `core_group` DROP COLUMN `net_space`;
                ALTER TABLE `core_group` DROP COLUMN `allow_out_size`;
                ALTER TABLE `core_group` DROP COLUMN `send_limit`;
                ALTER TABLE `core_group` DROP COLUMN `recv_limit`;
                ALTER TABLE `core_group` DROP COLUMN `is_pop`;
                ALTER TABLE `core_group` DROP COLUMN `is_smtp`;
                ALTER TABLE `core_group` DROP COLUMN `is_imap`;
                ALTER TABLE `core_group` DROP COLUMN `is_passwd`;
                ALTER TABLE `core_group` DROP COLUMN `passwd_day`;
                ALTER TABLE `core_group` DROP COLUMN `passwd_start`;
                ALTER TABLE `core_group` DROP COLUMN `passwd_type`;
                ALTER TABLE `core_group` DROP COLUMN `passwd_other`;
                ALTER TABLE `core_group` DROP COLUMN `passwd_forbid`;
                ALTER TABLE `core_group` DROP COLUMN `is_virus`;
                ALTER TABLE `core_group` DROP COLUMN `is_spam`;
                ALTER TABLE `core_group` DROP COLUMN `is_spf`;
                ALTER TABLE `core_group` DROP COLUMN `is_grey`;
                ALTER TABLE `core_group` DROP COLUMN `check_attach`;
                ALTER TABLE `core_group` DROP COLUMN `match_black`;
                ALTER TABLE `core_group` DROP COLUMN `check_spam`;
                ALTER TABLE `core_group` DROP COLUMN `is_formt`;
                ALTER TABLE `core_group` DROP COLUMN `spam_folder`;
                ALTER TABLE `core_group` DROP COLUMN `spam_subject_flag`;
                ALTER TABLE `core_group` DROP COLUMN `isolate_day`;
                ALTER TABLE `core_group` DROP COLUMN `is_send_isolate`;
                ALTER TABLE `core_group` DROP COLUMN `send_isolate_name`;
                ALTER TABLE `core_group` DROP COLUMN `isolate_url`;
                ALTER TABLE `core_group` DROP COLUMN `check_object`;
                ALTER TABLE `core_group` DROP COLUMN `check_local`;
                ALTER TABLE `core_group` DROP COLUMN `check_outside`;
                ALTER TABLE `core_group` DROP COLUMN `is_info`;
                ALTER TABLE `core_group` DROP COLUMN `is_passwd_mdf`;
                ALTER TABLE `core_group` DROP COLUMN `is_param`;
                ALTER TABLE `core_group` DROP COLUMN `is_signature`;
                ALTER TABLE `core_group` DROP COLUMN `is_autoreply`;
                ALTER TABLE `core_group` DROP COLUMN `is_autotans`;
                ALTER TABLE `core_group` DROP COLUMN `is_blackwhite`;
                ALTER TABLE `core_group` DROP COLUMN `is_tansdefault`;
                ALTER TABLE `core_group` DROP COLUMN `is_move`;
                ALTER TABLE `core_group` DROP COLUMN `is_suggest`;
                ALTER TABLE `core_group` DROP COLUMN `is_view`;
                ALTER TABLE `core_group` DROP COLUMN `is_filter`;
                ALTER TABLE `core_group` DROP COLUMN `is_smtp_tans`;
                ALTER TABLE `core_group` DROP COLUMN `passwd_level`;


                IF EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='core_group' AND COLUMN_NAME='is_passwd_first')
                THEN
                    ALTER TABLE `core_group` DROP COLUMN `is_passwd_first`;
                END IF;
                IF EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='core_group' AND COLUMN_NAME='oab_setting')
                THEN
                    ALTER TABLE `core_group` DROP COLUMN `oab_setting`;
                END IF;
                IF EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='core_group' AND COLUMN_NAME='oab_dept_list')
                THEN
                    ALTER TABLE `core_group` DROP COLUMN `oab_show_mod`;
                    ALTER TABLE `core_group` DROP COLUMN `oab_show_export`;
                    ALTER TABLE `core_group` DROP COLUMN `oab_dept_list`;
                END IF;
                IF EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='core_group' AND COLUMN_NAME='is_frequency')
                THEN
                    ALTER TABLE `core_group` DROP COLUMN `is_frequency`;
                    ALTER TABLE `core_group` DROP COLUMN `frequency_minute`;
                    ALTER TABLE `core_group` DROP COLUMN `frequency_minute_count`;
                    ALTER TABLE `core_group` DROP COLUMN `frequency_hour_count`;
                    ALTER TABLE `core_group` DROP COLUMN `frequency_day_count`;
                    ALTER TABLE `core_group` DROP COLUMN `frequency_operate`;
                END IF;
                IF EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='core_group' AND COLUMN_NAME='is_space_clean')
                THEN
                    ALTER TABLE `core_group` DROP COLUMN `is_space_clean`;
                    ALTER TABLE `core_group` DROP COLUMN `space_clean_normal`;
                    ALTER TABLE `core_group` DROP COLUMN `space_clean_sent`;
                    ALTER TABLE `core_group` DROP COLUMN `space_clean_spam`;
                    ALTER TABLE `core_group` DROP COLUMN `space_clean_trash`;
                END IF;
                IF EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='core_group' AND COLUMN_NAME='limit_whitelist')
                THEN
                    ALTER TABLE `core_group` DROP COLUMN `limit_whitelist`;
                END IF;
            END IF;
        END IF;
END $$
DELIMITER ;
call del_col_base();
drop PROCEDURE if EXISTS del_col_base;
-- 2.2.61 2018-12-13 组权限重新设计及数据兼容 end

-- 2.3.1 2018-12-14 发信查询拓展
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='core_send_status' AND COLUMN_NAME='src_recipient')
        THEN
        ALTER TABLE `core_send_status` ADD `src_recipient` varchar(200) DEFAULT NULL COMMENT '原始邮箱地址' AFTER `recipient`;
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;
-- 2.3.1 2018-12-14 发信查询拓展 end

-- 2.3.1 2019-01-18 修改ext_mailbox_extra默认值
DELIMITER $$
create procedure mdf_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='ext_mailbox_extra' AND COLUMN_NAME='data' AND COLUMN_DEFAULT IS NULL)
        THEN
        ALTER TABLE ext_mailbox_extra CHANGE `data` `data` varchar(500) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '统一为{value:xx}的json格式';
        END IF;
END $$
DELIMITER ;
call mdf_col_base();
drop PROCEDURE if EXISTS mdf_col_base;
-- 2.3.1 2019-01-18 修改ext_mailbox_extra默认值 end

-- 2.3.1 2019-01-23 中继core_relay增加验证帐号
DELIMITER $$
create procedure mdf_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='core_relay' AND COLUMN_NAME='account')
        THEN
        ALTER TABLE `core_relay` ADD `account` varchar(200) DEFAULT NULL COMMENT '帐号' AFTER `server`;
        ALTER TABLE `core_relay` ADD `password` varchar(200) DEFAULT NULL COMMENT '密码' AFTER `account`;
        END IF;
END $$
DELIMITER ;
call mdf_col_base();
drop PROCEDURE if EXISTS mdf_col_base;
-- 2.3.1 2019-01-23 中继core_relay增加验证帐号

-- 2.3.1 2019-01-31 修改文件名长度
drop PROCEDURE if EXISTS mdf_col_base;
DELIMITER $$
create procedure mdf_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='core_mail_attach' AND COLUMN_NAME = 'filename' AND COLUMN_TYPE='varchar(150)')
        THEN
        ALTER TABLE `core_mail_attach` modify `filename` VARCHAR(150) NOT NULL COMMENT '邮箱全名';
        END IF;
END $$
DELIMITER ;
call mdf_col_base();
drop PROCEDURE if EXISTS mdf_col_base;
-- 2.3.1 2019-01-31 修改文件名长度 end

-- 2.3.1 2019-01-31 投递状态增加邮件标题
drop PROCEDURE if EXISTS mdf_col_base;
DELIMITER $$
create procedure mdf_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='core_send_status' AND COLUMN_NAME = 'subject')
        THEN
        ALTER TABLE `core_send_status` ADD `subject` text DEFAULT NULL COMMENT '标题' AFTER `code`;
        END IF;
END $$
DELIMITER ;
call mdf_col_base();
drop PROCEDURE if EXISTS mdf_col_base;
-- 2.3.1 2019-01-31 投递状态增加邮件标题

-- 2.3.1 2019-03-22 core_alias唯一索引
drop PROCEDURE if EXISTS add_idx_base;
DELIMITER $$
create procedure add_idx_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.STATISTICS WHERE TABLE_SCHEMA='umail' AND table_name='core_alias' AND index_name = 'alias_uniq')
        THEN
            CREATE UNIQUE INDEX alias_uniq ON `core_alias`(`domain_id`, `type`, `source`);
        END IF;
END $$
DELIMITER ;
call add_idx_base();
drop PROCEDURE if EXISTS add_idx_base;
-- 2.3.1 2019-03-22 core_alias唯一索引 end

-- 2.3.1 2019-04-16 投递状态增加中继状态
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='core_send_status' AND COLUMN_NAME = 'relay_id')
        THEN
        ALTER TABLE `core_send_status` ADD `relay_server` varchar(100) DEFAULT NULL COMMENT '中继服务器' AFTER `subject`;
        ALTER TABLE `core_send_status` ADD `relay_id` varchar(32) DEFAULT NULL COMMENT '中继返回ID' AFTER `relay_server`;
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;
-- 2.3.1 2019-04-16 投递状态增加中继状态

-- 2.3.2 2019-04-28 wm_netdisk_share索引
drop PROCEDURE if EXISTS add_idx_base;
DELIMITER $$
create procedure add_idx_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.STATISTICS WHERE TABLE_SCHEMA='umail' AND table_name='wm_netdisk_share' AND index_name = 'share_idx')
        THEN
            CREATE INDEX share_idx ON `wm_netdisk_share`(`object_id`, `object_type`);
        END IF;
END $$
DELIMITER ;
call add_idx_base();
drop PROCEDURE if EXISTS add_idx_base;
-- 2.3.2 2019-04-28 wm_netdisk_share索引 end

-- 2.3.3 2019-05-29 core_mail_remark
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='core_mail_remark' AND COLUMN_NAME = 'updated')
        THEN
        ALTER TABLE `core_mail_remark` ADD `updated` datetime NULL DEFAULT NULL COMMENT '创建时间' AFTER `flag`;
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;
-- 2.3.3 2019-05-29 core_mail_remark end

-- 2.3.4 2019-05-30 短信授权码
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='core_mailbox' AND COLUMN_NAME='sms_password')
        THEN
            ALTER TABLE `core_mailbox` ADD COLUMN `sms_password` varchar(120) DEFAULT NULL COMMENT '短信授权码' AFTER `password`;
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;
-- 2.3.4 2019-05-30 短信授权码

-- 2.3.4 2019-06-10 日程定时发送改版
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
    IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='core_mail_schedule' AND COLUMN_NAME='receivers')
    THEN
        ALTER TABLE `core_mail_schedule` ADD `receivers` LONGTEXT CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '收件人列表，json' AFTER `created`;
        ALTER TABLE `core_mail_schedule` ADD `is_send` TINYINT(1) NOT NULL DEFAULT '0' COMMENT '是否已发送' AFTER `created`;
        ALTER TABLE `core_mail_schedule` ADD `uid` VARCHAR(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '0' COMMENT '草稿箱UID' AFTER `created`;
        ALTER TABLE `core_mail_schedule` ADD INDEX( `mailbox_id`, `uid`);
    END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;
-- 2.3.4 2019-06-10 日程定时发送改版 end

-- 2.3.4 2019-06-19 内容过滤器数据加上是否是管理员追加的标记
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
    IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='ext_cfilter_rule_new' AND COLUMN_NAME='is_admin')
    THEN
        ALTER TABLE `ext_cfilter_rule_new` ADD `is_admin` TINYINT(1) NOT NULL DEFAULT '0' COMMENT '是否管理员添加' AFTER `extype`;
    END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;
-- 2.3.4 2019-06-19 内容过滤器数据加上是否是管理员追加的标记 end

-- 2.2.60 2018-11-19 发信权限、收信权限兼容标记
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='core_mailbox' AND COLUMN_NAME='use_group')
        THEN
        ALTER TABLE `core_mailbox` ADD `use_group` TINYINT(2) NOT NULL DEFAULT '1' COMMENT '是否启用组权限' AFTER `limit_recv`;
        -- 2.3.6 后，因为 limit_send 默认值发生了改变，所以默认可以启用组权限
        UPDATE core_mailbox SET `use_group`='1';
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;
-- 2.2.60 2018-11-19 发信权限、收信权限兼容标记 end

-- 2.3.6 2019-07-15 core_mailbox 涉密评估添加时间描述
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='core_mailbox' AND COLUMN_NAME = 'pwd_days_time2')
        THEN
        ALTER TABLE `core_mailbox` ADD `pwd_days_time2` VARCHAR(100) NOT NULL DEFAULT '' COMMENT '密码有效开始时间' AFTER `pwd_days_time`;
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;
-- 2.3.6 2019-07-15 core_mailbox 涉密评估添加时间描述 end

-- 2.3.6 2019-07-19
-- postfix的spf配置已经不再使用，去掉数据库配置，避免查数据时被误导
DELETE FROM `core_config` WHERE `function`='spf';
-- 2.3.6 2019-07-19 end

-- 2.3.6 2019-08-05
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='core_trustip' AND COLUMN_NAME = 'auth')
        THEN
        ALTER TABLE `core_trustip` ADD `auth` TINYINT(2) NOT NULL DEFAULT '1' COMMENT '需要验证' AFTER `ip`;
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;
-- 2.3.6 2019-08-05 end

-- 2.3.11 2019-08-12
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='ext_imapmail' AND COLUMN_NAME = 'proto')
        THEN
            ALTER TABLE `ext_imapmail` ADD `proto` VARCHAR(10) NOT NULL DEFAULT 'imap' COMMENT 'pop3,imap' AFTER `mailbox`;
            ALTER TABLE `ext_imapmail` ADD `pop_folder` VARCHAR(200) NOT NULL DEFAULT 'INBOX' COMMENT '目标文件夹' AFTER `src_folder`;
            ALTER TABLE `ext_imapmail` ADD `pop_keepmail` TINYINT(2) NOT NULL DEFAULT '1' COMMENT 'pop是否保存邮件' AFTER `pop_folder`;
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;

drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='ext_imapmail' AND COLUMN_NAME = 'pwd_base64')
        THEN
            ALTER TABLE `ext_imapmail` ADD `pwd_base64` TINYINT(2) NOT NULL DEFAULT '1' COMMENT '是否是编码后密码' AFTER `src_password`;
            UPDATE `ext_imapmail` SET `pwd_base64`=0;
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;
-- 2.3.11 2019-08-12 end

-- 2.3.13 2019-08-27 微信回调接口
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='wx_config' AND COLUMN_NAME = 'callback_domain')
        THEN
            ALTER TABLE `wx_config` ADD `callback_domain` VARCHAR(200) NOT NULL DEFAULT '' COMMENT '微信回调接口' AFTER `appid`;
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;

-- 2.3.13 2019-08-27 微信回调接口 end

-- 2.3.13 2019-08-28 发信状态标记是否是外发
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
    IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='core_send_status' AND COLUMN_NAME='is_external')
    THEN
        ALTER TABLE `core_send_status` ADD `is_external` TINYINT(1) NOT NULL DEFAULT '0' COMMENT '是不是外部邮件';
    END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;
-- 2.3.13 2019-08-28 发信状态标记是否是外发 end

-- 2.3.13 2019-08-27 微信回调接口
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='wx_config' AND COLUMN_NAME = 'switch')
        THEN
            ALTER TABLE `wx_config` ADD `switch` TINYINT(1) NOT NULL DEFAULT '0' COMMENT '是否开启这个配置';
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;

-- 2.3.13 2019-08-27 微信回调接口 end

-- 2.3.15 2019-10-16 core_config唯一索引
drop PROCEDURE if EXISTS add_idx_base;
DELIMITER $$
create procedure add_idx_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.STATISTICS WHERE TABLE_SCHEMA='umail' AND table_name='core_config' AND index_name = 'config_key')
        THEN
            DELETE a.* FROM core_config AS a, (
                    SELECT `function`, COUNT(*), MAX(id) AS id
                      FROM core_config
                      GROUP BY `function` HAVING COUNT(*)>1
                    ) AS b
            WHERE a.function=b.function and a.id < b.id;
            CREATE UNIQUE INDEX config_key ON `core_config`(`function`);
        END IF;
END $$
DELIMITER ;
call add_idx_base();
drop PROCEDURE if EXISTS add_idx_base;
-- 2.3.15 2019-10-16

-- 2.3.16 邮箱搬家增加是否验证成功标记
drop PROCEDURE if EXISTS add_col_base;
DELIMITER $$
create procedure add_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='ext_imapmail' AND COLUMN_NAME = 'is_login')
        THEN
            ALTER TABLE `ext_imapmail` ADD `is_login` TINYINT(2) NOT NULL DEFAULT '0' COMMENT '是否验证成功 1:成功,0:失败' AFTER `pwd_base64`;
            UPDATE `ext_imapmail` SET `is_login`=1;
        END IF;
END $$
DELIMITER ;
call add_col_base();
drop PROCEDURE if EXISTS add_col_base;
-- 2.3.16 邮箱搬家增加是否验证成功标记 end

-- 2.3.17 2020-03-11 超级管理后台中 安全设置/密码审核列表 隐藏
drop PROCEDURE if EXISTS mdf_col_base;
DELIMITER $$
create procedure mdf_col_base()
BEGIN
        IF EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='perm_mypermission')
        THEN
            UPDATE `perm_mypermission` SET `is_nav` = 0, `is_default` = 0 WHERE `name` = 'password_review';
        END IF;
END $$
DELIMITER ;
call mdf_col_base();
drop PROCEDURE if EXISTS mdf_col_base;
-- 2.3.17 2020-03-11 超级管理后台中 安全设置/密码审核列表 隐藏  end

-- 2.3.17 2020-05-14 修改附件大小限制
drop PROCEDURE if EXISTS mdf_col_base;
DELIMITER $$
create procedure mdf_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='core_mail_attach' AND COLUMN_NAME = 'size' AND COLUMN_TYPE='BIGINT(20)')
        THEN
            ALTER TABLE `core_mail_attach` MODIFY `size` BIGINT(20) NOT NULL DEFAULT '0';
        END IF;
END $$
DELIMITER ;
call mdf_col_base();
drop PROCEDURE if EXISTS mdf_col_base;
-- 2.3.17 2020-05-14 修改附件大小限制 end

-- 2.3.17 2020-10-14 增加字段(operator optime opip)
drop PROCEDURE if EXISTS mdf_col_base;
DELIMITER $$
create procedure mdf_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='ext_sequester_mail' AND COLUMN_NAME IN ('operator','optime','opip'))
        THEN
            ALTER TABLE `ext_sequester_mail` ADD `operator` VARCHAR(50) NULL;
            ALTER TABLE `ext_sequester_mail` ADD `optime` DATETIME NULL;
            ALTER TABLE `ext_sequester_mail` ADD `opip` VARCHAR(50) NULL;
        END IF;
END $$
DELIMITER ;
call mdf_col_base();
drop PROCEDURE if EXISTS mdf_col_base;
-- 2.3.17 2020-10-14 增加字段(operator optime opip) end

-- 2.3.18 2020-12-01 解除企业网盘2G大小限制
drop PROCEDURE if EXISTS mdf_col_base;
DELIMITER $$
create procedure mdf_col_base()
BEGIN
        IF NOT EXISTS (SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='umail' AND table_name='wm_company_file' AND COLUMN_NAME = 'file_size' AND COLUMN_TYPE='BIGINT(20)')
        THEN
            ALTER TABLE `wm_company_file` MODIFY `file_size` BIGINT(20) NOT NULL DEFAULT '0';
        END IF;
END $$
DELIMITER ;
call mdf_col_base();
drop PROCEDURE if EXISTS mdf_col_base;
-- 2.3.18 2020-12-01 解除企业网盘2G大小限制 end