#!/usr/bin/env bash

set -o pipefail
#
#if [[ "$(uname -r)" =~ ^4\.15\.0-60 ]]; then
#  echo "DO NOT RUN umail ON THIS UBUNTU KERNEL!";
#  echo "Please update to 5.x or use another distribution."
#  exit 1
#fi
#
#if [[ "$(uname -r)" =~ ^4\.4\. ]]; then
#  if grep -q Ubuntu <<< $(uname -a); then
#    echo "DO NOT RUN umail ON THIS UBUNTU KERNEL!";
#    echo "Please update to linux-generic-hwe-16.04 by running \"apt-get install --install-recommends linux-generic-hwe-16.04\""
#  fi
#  exit 1
#fi

if grep --help 2>&1 | grep -q -i "busybox"; then
  echo "BusyBox grep detected, please install gnu grep, \"apk add --no-cache --upgrade grep\""
  exit 1
fi
if cp --help 2>&1 | grep -q -i "busybox"; then
  echo "BusyBox cp detected, please install coreutils, \"apk add --no-cache --upgrade coreutils\""
  exit 1
fi

for bin in openssl curl docker-compose docker git awk sha1sum; do
  if [[ -z $(which ${bin}) ]]; then echo "Cannot find ${bin}, exiting..."; exit 1; fi
done

if [ -f umail.conf ]; then
  read -r -p "A config file exists and will be overwritten, are you sure you want to contine? [y/N] " response
  case $response in
    [yY][eE][sS]|[yY])
      mv umail.conf umail.conf_$(date +%Y%m%d%H%M%S)
      ;;
    *)
      exit 1
    ;;
  esac
fi

echo "Press enter to confirm the detected value '[value]' where applicable or enter a custom value."
while [ -z "${DOMAIN}" ]; do
  read -p "Mail server Domain: " -e DOMAIN
done

if [ -a /etc/timezone ]; then
  DETECTED_TZ=$(cat /etc/timezone)
elif [ -a /etc/localtime ]; then
  DETECTED_TZ=$(readlink /etc/localtime|sed -n 's|^.*zoneinfo/||p')
fi

while [ -z "${UMAIL_TZ}" ]; do
  if [ -z "${DETECTED_TZ}" ]; then
    read -p "Timezone: " -e UMAIL_TZ
  else
    read -p "Timezone [${DETECTED_TZ}]: " -e UMAIL_TZ
    [ -z "${UMAIL_TZ}" ] && UMAIL_TZ=${DETECTED_TZ}
  fi
done

cat << EOF > umail.conf
COMPOSE_PROJECT_NAME=umaildockerized
# ------------------------------
# umail web ui configuration
# ------------------------------
DOMAIN=${DOMAIN}


# ------------------------------
# SQL database configuration
# ------------------------------

DBNAME=umail
DBUSER=umail

# Please use long, random alphanumeric strings (A-Za-z0-9)

DBPASS=$(LC_ALL=C </dev/urandom tr -dc A-Za-z0-9 | head -c 28)
DBROOT=$(LC_ALL=C </dev/urandom tr -dc A-Za-z0-9 | head -c 28)

POSTGRES_DB=admin
POSTGRES_USER=admin
POSTGRES_PASSWORD=$(LC_ALL=C </dev/urandom tr -dc A-Za-z0-9 | head -c 28)

# ------------------------------
# HTTP/S Bindings
# ------------------------------

# You should use HTTPS, but in case of SSL offloaded reverse proxies:
# Might be important: This will also change the binding within the container.
# If you use a proxy within Docker, point it to the ports you set below.
# Do _not_ use IP:PORT in HTTP(S)_BIND or HTTP(S)_PORT
# IMPORTANT: Do not use port 8081, 9081 or 65510!

HTTP_PORT=80
HTTP_BIND=0.0.0.0

HTTPS_PORT=443
HTTPS_BIND=0.0.0.0

# ------------------------------
# Other bindings
# ------------------------------
# You should leave that alone
# Format: 11.22.33.44:25 or 0.0.0.0:465 etc.

SMTP_PORT=25
SMTPS_PORT=465
SUBMISSION_PORT=587
IMAP_PORT=143
IMAPS_PORT=993
POP_PORT=110
POPS_PORT=995
SQL_PORT=127.0.0.1:13306
REDIS_PORT=127.0.0.1:16379

IPV4_NETWORK=172.22.1
# Your timezone

TZ=${UMAIL_TZ}

EOF

mkdir -p data/assets/ssl

chmod 600 umail.conf
source umail.conf

if [ -f data/conf/custom.conf ]; then
 mv data/conf/custom.conf data/conf/custom.conf_$(date +%Y%m%d%H%M%S)
fi
cat << EOF > data/conf/custom.conf
[system]
domain   = ${DOMAIN}
mailroot = /usr/local/u-mail/data/mailbox
logroot = /usr/local/u-mail/log
netdiskroot = /usr/local/u-mail/data/www/webmail/netdisk
security_mode = 0
docker = 1
# wx_host = mail.test.com
# wx_ssl = 0

[service-moving]
# 默认任务数量
thread_num = 200
# 每个任务每次拉取邮件数量
receive_per_task = 100

[umail-deliver]
process_num = 1
thread_num = 50

[umail-smtp]
process_num = 1
thread_num = 50

[mysql]
host   = mysql
port   = 3306
sock   = /var/run/mysqld/mysqld.sock
user   = ${DBUSER}
pass = ${DBPASS}
dbname = ${DBNAME}
[ssl]
key  = /usr/local/u-mail/data/assets/ssl/key.pem
cert = /usr/local/u-mail/data/assets/ssl/cert.pem

[nginx]
port = 80

[apache]
port = 99

[redis]
host = redis
port = 6379
sock = /var/run/redis.sock

[anti-virus]
host = clamd
port = 3310
sock = /usr/local/u-mail/data/clamav/run/clamd.sock


[anti-spam-1]
host = 127.0.0.1
port = 10031

[anti-spam-2]
host = 127.0.0.1
port = 10032

[anti-spam-3]
host = 127.0.0.1
port = 10034

[misc]
relay_server = relay.comingchina.com
EOF

cp data/assets/mysql/init.sql.template data/assets/mysql/init.sql
perl -p -i -e "s/test\.test/${DOMAIN}/gi;" "data/assets/mysql/init.sql"
ln -sf umail.conf .env
exit

# copy but don't overwrite existing certificate
echo "Generating snake-oil certificate..."
# Making Willich more popular
openssl genrsa -out data/assets/ssl-example/key.pem 4096
openssl req -x509 -newkey rsa:4096 -keyout data/assets/ssl-example/key.pem -out data/assets/ssl-example/cert.pem -days 365 -subj "/C=DE/ST=NRW/L=Willich/O=umail/OU=umail/CN=${DOMAIN}" -sha256 -nodes
echo "Copying snake-oil certificate..."
cp -n -d data/assets/ssl-example/*.pem data/assets/ssl/
