#!/usr/bin/env bash

[[ -f ../umail.conf ]] && source ../umail.conf

if [[ -z ${DBUSER} ]] || [[ -z ${DBPASS} ]] || [[ -z ${DBNAME} ]]; then
	echo "Cannot find umail.conf, make sure this script is run from within the umail.conf folder."
	exit 1
fi

echo -n "Checking MySQL service... "
if [[ -z $(docker ps -qf name=umail_mysql) ]]; then
	echo "failed"
	echo "MySQL (umail_mysql) is not up and running, exiting..."
	exit 1
fi

echo "OK"
read -r -p "Are you sure you want to update the umail databases ? [y/N] " response
response=${response,,}    # tolower
if [[ "$response" =~ ^(yes|y)$ ]]; then
	echo -e "\nWorking, please wait..."
	for UPDATE_TABLE in base_table.sql base_update.sql
	    do
	        echo "update the umail databases: ${UPDATE_TABLE}"
	        docker exec -it $(docker ps -qf name=umail_mysql) mysql -u${DBUSER} -p${DBPASS} ${DBNAME} -e "source /update/${UPDATE_TABLE}"
        done
else
	echo "Operation canceled."
fi
